# EUPT XML

(Vorerst beinhaltet diese Readme die Anfänge einer Dokumentation des Schemas)

## Schemadokumentation

### Metadaten

#### Lizenz
Lizenzangaben werden mittels `tei:availability/tei:licence` erfasst. In `tei:licence` wird als textlicher Inhalt der offizielle Name der Lizenz angegeben. Mit dem Attribut `@target` wird der URI zur ausführlichen Definition der Lizenzbestimmungen angegeben.

##### Beispiel:
```
<tei:availability>
    <tei:licence target="https://creativecommons.org/licenses/by-sa/4.0/">CC-BY-SA-4.0</tei:licence>
</tei:availability>
```

Dies entspricht den [Empfehlungen der KIM-Gruppe Lizenzen](https://wiki.dnb.de/pages/viewpage.action?pageId=217533672).

##### HTML-Serialisierung
Die Lizenzangaben werden im Metadatenpanel angegeben.

### Daten

#### Hervorhebungen
Hervorhebungen werden mittels `hi` erfasst. Die Art der Hervorhebung wird mittels `@rend` definiert. Mögliche Werte für `@rend` sind:

- `bold`: Fett
- `italics`: Kursiv (Default)
- `sub`: Tiefgestellt
- `super`: Hochgestellt
- `under`: Unterstrichen

##### Beispiel
```
In der Abfolge der Erzählsequenzen <hi rend="bold">Angebot</hi> - <hi rend="under">Ablehnung des Angebots</hi> - <hi>Äußerung des eigentlichen Wunsches</hi> erhält Kirtus tatsächliches Anliegen nämlich besonderes Gewicht:
```

##### HTML-Serialisierung
Darstellung des Textes entsprechend des Werts von `@rend`.

#### Kommentare
Kommentare werden mittels `note` erfasst. Mittels `@target` können Kommentare auf verschiedene Elemente verweisen (bspw. `seg`, `g`, `part`, `phr`, `w`).

Kommentare können einen oder mehrere Typen zugewiesen werden. Hierfür wird das Attribut `@type` genutzt. Erlaubte Werte sind:

  - "con": Inhalt
  - "gr": Grammatik
  - "lx": Lexik
  - "poet": Poetologie

Kommentare können mehrere Absätze enthalten. Dann muss der Inhalt des `note` ausschließlich aus [`p`](#absätze) bestehen (das `note` darf also keinen textlichen Inhalt haben).

Alternativ kann das `note` in beliebiger Reihenfolge eine beliebige Anzahl an [`ana`](#ana), [`hi`](#hervorhebungen), [`quote`](#zitate), [`ref`](#verweise), [`textBlock`](#ugaritische-textblöcke), [`bibl`](#literaturverweise) und Text enthalten.

#### Absätze

#### Ugaritische Textblöcke
Ugaritischer Text außerhalb der [Transliteration](#transliteration) und [Vokalisation](#vokalisation-und-übersetzung) wird mittels `textBlock` erfasst.

`textBlock` darf eine beliebige Anzahl Elemente aus einer der folgenden Elementgruppen enthalten:

- [`column`](#kolumns)
- [`line`](#zeilen) und [`tei:damage`](#damage)
- [`part`](#part), [`seg`](#seg), [`g`](#g), [`lb`](#linebeginning) sowie die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription)
- [`pc`](#pc), [`phr`](#phr), [`w`](#w), [`lb`](#linebeginning) sowie die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription)

##### Beispiel
```
<textBlock><tei:supplied>D</tei:supplied> <segg>ṮDṮ</seg></textBlock>
```

##### HTML-Serialisierung
Der ugaritische Text soll genauso dargestellt werden wie in der [Transliteration](#transliteration) und in der [Vokalisation](#vokalisation-und-übersetzung) .

#### Zitate
Zitate werden mittels `quote` erfasst.

`quote` darf in beliebiger Reihenfolge eine beliebige Anzahl an [`ana`](#ana), [`hi`](#hervorhebungen), [`quote`](#zitate), [`ref`](#verweise), [`bibl`](#literaturverweise), [`pc`](#pc), [`phr`](#phr), [`w`](#w), [`lb`](#lb), [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

##### HTML-Serialisierung
In der HTML-Serialisierung werden Anführungszeichen vor und nach dem Zitat eingefügt.

#### Literaturverweise

#### Verweise

#### Ana

#### Linebeginning

#### pc

#### metamark

### Transliteration

#### Kolumns

Die Textspalten einer Tontafel werden mittels `column` erfasst.

`column` wird mittels `@n` eine Nummer zugewiesen. Es ist möglich, `column` eine `@xml:id` und/oder `xml:base` zuzuweisen.

`column` darf [`line`](#zeilen), [`note`](#kommentare), [`tei:damage`](#teidamage) sowie [`metamark`](#metamark) enthalten.

#### Zeilen

#### Part

#### Seg

#### G
Ein Zeichen oder eine Glyphe wird mittels `g` erfasst.

`g` kann eine `@xml:id` sowie ein `@ana` zugewiesen werden. Mittels `@cert` kann angegeben werden, ob man sich sicher ist, dass an dieser Stelle tatsächlich das erfasste Zeichen steht. Wenn ja, wird das `g` mit `@cert="high"` spezifiziert, wenn nicht dann mit `@cert="low"`. Der Default-Wert ist "high".

Das Zeichen beziehungsweise die Glyphe wird als Unicode-Zeichen im textlichen Inhalt von `g` erfasst.

### Vokalisation und Übersetzung

#### phr

#### w
Einzelne Wörter werden mittels `w` erfasst.

`w` kann eine `@xml:id`, ein `@ana`, ein `@corresp` sowie ein `@lemma` zugewiesen werden. Mittels `@cert` kann angegeben werden, ob man sich sicher ist, dass an dieser Stelle tatsächlich das erfasste Zeichen steht. Wenn ja, wird das `w` mit `@cert="high"` spezifiziert, wenn nicht, dann mit `@cert="low"`. Der Default-Wert ist "high".

`w` darf [`m`](#m), [`lb`](#linebeginning), die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) sowie Text enthalten.

#### m

#### Translation
Die Übersetzung wird mittels `translation` erfasst.

Mit dem Attribut `@xml:lang` wird die Sprache der Übersetzung angegeben. Mittels `@cert` kann angegeben werden, ob man sich sicher ist, dass dies die richtige Übersetzung ist. Wenn ja, wird das `translation` mit `@cert="high"` spezifiziert, wenn nicht, dann mit `@cert="low"`. Der Default-Wert ist "high".

`translation` darf [`pc`](#pc), [`phr`](#phr), [`w`](#w), [`lb`](#linebeginning), die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription), [`hi`](#hervorhebungen) sowie Text enthalten.

### Elemente zur Beschreibung der Transkription

#### tei:choice

#### tei:sic

`tei:sic` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:corr

`tei:corr` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:reg

`tei:reg` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:orig

`tei:orig` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:add

`tei:add` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:del

`tei:del` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:unclear
Wenn nicht klar ist, ob ein Zeichen tatsächlich existiert, wird dieses Zeichen in `tei:unclear` erfasst.

`tei:unclear` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

##### HTML-Serialisierung
In der HTML-Serialisierung müssen runde Klammern um den Inhalt von `tei:unclear` eingefügt werden.

#### tei:damage

`tei:damage` zeigt an, dass an dieser Stelle der Text beschädigt ist.

Mittels `@unit` wird spezifiziert, ob ein oder mehrere Zeichen (`character`) oder Zeilen (`line`) beschädigt sind. Die Anzahl der Zeichen bzw. Zeilen wird mittels `@atLeast` (Mindestanzahl) und `@atMost` (Maximalanzahl) angegeben.

`tei:damage` darf `pc`, `phr`, `w`, `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

##### HTML-Serialisierung
In der HTML-Serialisierung werden eckige Klammern um den Inhalt von `tei:damage` gesetzt.

#### tei:restore

`tei:restore` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:supplied

`tei:supplied` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:surplus

`tei:surplus` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:secl

`tei:secl` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:mod

`tei:mod` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:redo

`tei:redo` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:retrace

`tei:retrace` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.

#### tei:undo

`tei:undo` darf `g`, `part`, `seg`, `lb`, die [Elemente zur Beschreibung der Transkription](#elemente-zur-beschreibung-der-transkription) und Text enthalten.